#
# spec file for package kubesec
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kubesec
Version:        2.14.2
Release:        1.2
Summary:        Security risk analysis for Kubernetes resources
License:        Apache-2.0
URL:            https://github.com/controlplaneio/kubesec
Source:         kubesec-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.23.1
BuildRequires:  zsh

%description
Security risk analysis for Kubernetes resources

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%setup -q
%setup -q -T -D -a 1

%build
# version output seems to be broken upstream
# https://github.com/controlplaneio/kubesec/issues/337
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-w -X github.com/controlplaneio/kubesec/v2/cmd.commit=v%{version} \
   -X github.com/controlplaneio/kubesec/v2/cmd.version=%{version} \
   -X github.com/controlplaneio/kubesec/v2/cmd.date=$BUILD_DATE" \
   -o bin/kubesec .

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Tue Nov 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.14.2:
  * docs: add release note for v2.14.2
  * chore(deps): bump the gomod group across 1 directory with 6
    updates
  * chore(deps): bump the gha group across 1 directory with 2
    updates
  * Update go to 1.22.7 for fixing High vulnerability
  * Update go to 1.22.7 for fixing High vulnerability
* Tue Aug 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.14.1:
  * chore: add update release notes
  * chore: simplify alpine container build
  * chore: add schema downloader to scratch container release
  * chore(deps): bump k8s schema version and tweak readme notes
  * chore(deps): bump container base images
  * chore(deps): update go dependencies
  * chore: update goreleaser config for v2
  * chore(deps): bump the gha group across 1 directory with 4
    updates
  * fix: scan entire branch with trufflehog
  * chore(deps): bump the gha group with 3 updates
  * chore(deps): bump google.golang.org/protobuf from 1.31.0 to
    1.33.0
  * chore(deps): bump the gha group with 2 updates
  * chore(deps): bump the gha group with 6 updates
  * chore(deps): bump the gomod group with 1 update
  * chore: correct webhook release name and tag
  * chore: manual workflow for releasing kubesec-workflow for now
* Thu Nov 23 2023 kastl@b1-systems.de
- Update to version 2.14.0:
  * Bump dependencies
  * Allow for providing an ip and port when running kubesec as
    a server
  * CI improvements
* Thu Jul 20 2023 Johannes Kastl <kastl@b1-systems.de>
- fix version output (see
  https://github.com/controlplaneio/kubesec/pull/480)
* Tue Mar 28 2023 Johannes Kastl <kastl@b1-systems.de>
- bash-completion subpackage now Requires bash-completion
* Tue Mar 28 2023 Johannes Kastl <kastl@b1-systems.de>
- new package kubesec: Security risk analysis for Kubernetes resources
